Index: src/southbridge/intel/i82371eb/Config.lb
===================================================================
--- src/southbridge/intel/i82371eb/Config.lb    (revision 2639) 
+++ src/southbridge/intel/i82371eb/Config.lb    (working copy) 
@@ -22,4 +22,5 @@
 
 driver i82371eb.o
 driver i82371eb_smbus.o
+driver i82371eb_ide.o 
 
Index: src/southbridge/intel/i82371eb/i82371eb_ide.c
===================================================================
--- src/southbridge/intel/i82371eb/i82371eb_ide.c    (revision 0) 
+++ src/southbridge/intel/i82371eb/i82371eb_ide.c    (revision 0) 
@@ -0,0 +1,52 @@
+/* 
+ * This file is part of the LinuxBIOS project. 
+ * 
+ * Copyright (C) 2007 Ceri Coburn <ceri.coburn@gmail.com> 
+ * 
+ * This program is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+ */ 
+ 
+ 
+#include <console/console.h> 
+#include <device/device.h> 
+#include <device/pci.h> 
+#include <device/pci_ids.h> 
+#include <device/pci_ops.h> 
+#include "i82371eb.h" 
+ 
+static void ide_init(struct device *dev) 
+{ 
+    printk_debug("Enabling primary IDE interface\n"); 
+    pci_write_config16(dev,IDETIM_PRIMARY,0xa307); 
+ 
+    //printk_debug("Enabling secondary IDE interface\n"); 
+    //pci_write_config16(dev,IDETIM_SECONDARY,0xa307);     
+ 
+} 
+ 
+static struct device_operations ide_ops = { 
+    .read_resources        = pci_dev_read_resources, 
+    .set_resources         = pci_dev_set_resources, 
+    .enable_resources     = pci_dev_enable_resources, 
+    .init             = ide_init, 
+    .enable         = i82371eb_enable, 
+}; 
+ 
+ 
+static struct pci_driver ide_driver __pci_driver = { 
+    .ops = &ide_ops, 
+    .vendor = PCI_VENDOR_ID_INTEL, 
+    .device = PCI_DEVICE_INTEL_PIIX4E_IDE 
+}; 
Index: src/southbridge/intel/i82371eb/i82371eb.h
===================================================================
--- src/southbridge/intel/i82371eb/i82371eb.h    (revision 2639) 
+++ src/southbridge/intel/i82371eb/i82371eb.h    (working copy) 
@@ -27,6 +27,14 @@
 
 void i82371eb_enable(device_t dev);
 
+#define PCI_DEVICE_INTEL_PIIX4E 0x0601 
+#define PCI_DEVICE_INTEL_PIIX4E_IDE 0x7111 
+ 
+#define IDETIM_PRIMARY 0x40 
+#define IDETIM_SECONDARY 0x42 
+#define UDMACTL 0x48 
+ 
+ 
 #endif
 
 #endif                /* I82371EB_H */
Index: src/superio/nsc/pc87338/Config.lb
===================================================================
--- src/superio/nsc/pc87338/Config.lb    (revision 0) 
+++ src/superio/nsc/pc87338/Config.lb    (revision 0) 
@@ -0,0 +1,23 @@
+## 
+## This file is part of the LinuxBIOS project. 
+## 
+## Copyright (C) 2006 Uwe Hermann <uwe@hermann-uwe.de> 
+## 
+## This program is free software; you can redistribute it and/or modify 
+## it under the terms of the GNU General Public License as published by 
+## the Free Software Foundation; either version 2 of the License, or 
+## (at your option) any later version. 
+## 
+## This program is distributed in the hope that it will be useful, 
+## but WITHOUT ANY WARRANTY; without even the implied warranty of 
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+## GNU General Public License for more details. 
+## 
+## You should have received a copy of the GNU General Public License 
+## along with this program; if not, write to the Free Software 
+## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+## 
+ 
+config chip.h 
+object superio.o 
+ 
Property changes on: src/superio/nsc/pc87338/Config.lb
___________________________________________________________________
Name: svn:executable
   + *
Index: src/superio/nsc/pc87338/pc87338.h
===================================================================
--- src/superio/nsc/pc87338/pc87338.h    (revision 0) 
+++ src/superio/nsc/pc87338/pc87338.h    (revision 0) 
@@ -0,0 +1,32 @@
+/* 
+ * This file is part of the LinuxBIOS project. 
+ * 
+ * Copyright (C) 2006 Uwe Hermann <uwe@hermann-uwe.de> 
+ * 
+ * This program is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+ */ 
+ 
+/* Datasheet: http://www.ite.com.tw/product_info/PC/Brief-IT8661_2.asp */ 
+/* Status: Untested on real hardware, but it compiles. */ 
+ 
+/* This chip doesn't seem to have keyboard and mouse support. */ 
+ 
+#define NSC87338_FDC  0x00 /* Floppy */ 
+#define NSC87338_SP1  0x01 /* Com1 */ 
+#define NSC87338_SP2  0x02 /* Com2 */ 
+#define NSC87338_PP   0x03 /* Parallel port */ 
+#define NSC87338_IR   0x04 /* IR */ 
+#define NSC87338_GPIO 0x05 /* GPIO & Alternate Function Configuration */ 
+ 
Property changes on: src/superio/nsc/pc87338/pc87338.h
___________________________________________________________________
Name: svn:executable
   + *
Index: src/superio/nsc/pc87338/superio.c
===================================================================
--- src/superio/nsc/pc87338/superio.c    (revision 0) 
+++ src/superio/nsc/pc87338/superio.c    (revision 0) 
@@ -0,0 +1,83 @@
+/* 
+ * This file is part of the LinuxBIOS project. 
+ * 
+ * Copyright (C) 2006 Uwe Hermann <uwe@hermann-uwe.de> 
+ * Copyright (C) 2007 Ceri Coburn <ceri.coburn@gmail.com> 
+ * 
+ * This program is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+ */ 
+ 
+/* This chip doesn't seem to have keyboard and mouse support. */ 
+ 
+#include <device/device.h> 
+#include <device/pnp.h> 
+#include <uart8250.h> 
+#include "chip.h" 
+#include "pc87338.h" 
+ 
+static void init(device_t dev) 
+{ 
+    struct superio_nsc_pc87338_config *conf; 
+    struct resource *res0, *res1; 
+ 
+    if (!dev->enabled) { 
+        return; 
+    } 
+ 
+    conf = dev->chip_info; 
+ 
+    switch (dev->path.u.pnp.device) { 
+    case NSC87338_FDC: /* TODO. */ 
+        break; 
+    case NSC87338_SP1: 
+        res0 = find_resource(dev, PNP_IDX_IO0); 
+        init_uart8250(res0->base, &conf->com1); 
+        break; 
+    case NSC87338_SP2: 
+        res0 = find_resource(dev, PNP_IDX_IO0); 
+        init_uart8250(res0->base, &conf->com2); 
+        break; 
+    case NSC87338_PP: /* TODO. */ 
+        break; 
+    case NSC87338_IR: /* TODO. */ 
+        break; 
+    } 
+} 
+ 
+static struct device_operations ops = { 
+    .read_resources   = pnp_read_resources, 
+    .set_resources    = pnp_set_resources, 
+    .enable_resources = pnp_enable_resources, 
+    .enable           = pnp_enable, 
+    .init             = init, 
+}; 
+ 
+/* TODO: FDC, PP, IR, GPIO. */ 
+static struct pnp_info pnp_dev_info[] = { 
+ { &ops, NSC87338_SP1,  PNP_IO0 | PNP_IRQ0, { 0x7f8, 0 }, }, 
+ { &ops, NSC87338_SP2,  PNP_IO0 | PNP_IRQ0 | PNP_DRQ0 | PNP_DRQ1, { 0x7f8, 0 }, }, 
+}; 
+ 
+static void enable_dev(struct device *dev) 
+{ 
+    pnp_enable_devices(dev, &pnp_ops, 
+        sizeof(pnp_dev_info)/sizeof(pnp_dev_info[0]), pnp_dev_info); 
+} 
+ 
+struct chip_operations superio_ite_it8661f_ops = { 
+    CHIP_NAME("NSC PC87338 Super I/O") 
+    .enable_dev = enable_dev, 
+}; 
+ 
Property changes on: src/superio/nsc/pc87338/superio.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/superio/nsc/pc87338/chip.h
===================================================================
--- src/superio/nsc/pc87338/chip.h    (revision 0) 
+++ src/superio/nsc/pc87338/chip.h    (revision 0) 
@@ -0,0 +1,37 @@
+/* 
+ * This file is part of the LinuxBIOS project. 
+ * 
+ * Copyright (C) 2006 Uwe Hermann <uwe@hermann-uwe.de> 
+ * Copyright (C) 2007 Ceri Coburn <ceri.coburn@gmail.com> 
+ * 
+ * This program is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+ */ 
+ 
+#ifndef _SUPERIO_NSC_PC87338 
+#define _SUPERIO_NSC_PC87338 
+ 
+/* This chip doesn't seem to have keyboard and mouse support. */ 
+ 
+#include <device/device.h> 
+#include <uart8250.h> 
+ 
+extern struct chip_operations superio_nsc_pc87338_ops; 
+ 
+struct superio_nsc_pc87338_config { 
+    struct uart8250 com1, com2; 
+}; 
+ 
+#endif /* _SUPERIO_ITE_IT8661F */ 
+ 
Property changes on: src/superio/nsc/pc87338/chip.h
___________________________________________________________________
Name: svn:executable
   + *
Index: src/superio/nsc/pc87338/pc87338_early_serial.c
===================================================================
--- src/superio/nsc/pc87338/pc87338_early_serial.c    (revision 0) 
+++ src/superio/nsc/pc87338/pc87338_early_serial.c    (revision 0) 
@@ -0,0 +1,93 @@
+/* 
+ * This file is part of the LinuxBIOS project. 
+ * 
+ * Copyright (C) 2006 Uwe Hermann <uwe@hermann-uwe.de> 
+ * Copyright (C) 2007 Ceri Coburn <ceri.coburn@gmail.com> 
+ * 
+ * This program is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+ */ 
+ 
+#include <arch/romcc_io.h> 
+#include "pc87338.h" 
+ 
+/* The base address is 0x3f0, 0x3bd, or 0x370, depending on config bytes. */ 
+#define SIO_BASE                   0x2e 
+#define SIO_INDEX                  SIO_BASE 
+#define SIO_DATA                   SIO_BASE+1 
+ 
+/* Global configuration registers. */ 
+#define NSC87338_CONFIG_REG_FER      0x00  /* Function Enable Register (PP, FDC, SSC1/2). */ 
+#define NSC87338_CONFIG_REG_S1BAH    0x45  /* SCC1 Base address high byte */ 
+#define NSC87338_CONFIG_REG_S1BAL    0x46  /* SCC1 Base address low byte */ 
+ 
+//#define NSC87338_CONFIG_REG_LDN     0x07   /* Logical Device Number. */ 
+//#define NSC87338_CONFIG_REG_LDE     0x23   /* PnP Logical Device Enable. */ 
+//#define NSC87338_CONFIG_REG_SWSUSP  0x24   /* Software Suspend + Clock Select. */ 
+ 
+#define NSC87338_CONFIGURATION_PORT 0x0279 /* Write-only. */ 
+ 
+/* Special values used for entering MB PnP mode. The first four bytes of 
+   each line determine the address port, the last four are data. */ 
+static const uint8_t init_values[] = { 
+    0x6A, 0xB5, 0xDA, 0xED, 0xF6, 0xFB, 0x7D, 0xBE, 
+    0xDF, 0x6F, 0x37, 0x1B, 0x0D, 0x86, 0xC3, 0x61, 
+    0xB0, 0x58, 0x2C, 0x16, 0x8B, 0x45, 0xA2, 0xD1, 
+    0xE8, 0x74, 0x3A, 0x9D, 0xCE, 0xE7, 0x00, 0x00 
+}; 
+ 
+/* The content of IT8661F_CONFIG_REG_LDN (index 0x07) must be set to the 
+   LDN the register belongs to, before you can access the register. */ 
+static void pc87338_sio_write(uint8_t reg_index, uint8_t value) 
+{ 
+    outb(reg_index, SIO_INDEX); 
+    outb(value, SIO_DATA); 
+} 
+ 
+ 
+/* Enable the peripheral devices on the IT8661F Super I/O chip. */ 
+static void pc87338_enable_serial(device_t dev, unsigned iobase) 
+{ 
+    uint8_t i; 
+ 
+    /* Sequentially write the 32 special PnP values. */ 
+    //for (i = 0; i < 32; i++) { 
+    //    outb(init_values[i], NSC87338_CONFIGURATION_PORT); 
+    //} 
+ 
+    ///* Write out our INDEX/BASE address after the PnP special values */ 
+    //outb( (SIO_BASE & 0xff00) >> 8, NSC87338_CONFIGURATION_PORT); 
+    //outb(  SIO_BASE & 0xff , NSC87338_CONFIGURATION_PORT); 
+ 
+    /* Set th address of SSC1 */ 
+    //pc87338_sio_write(NSC87338_CONFIG_REG_S1BAH,(iobase & 0xff00) << 8); 
+    //pc87338_sio_write(NSC87338_CONFIG_REG_S1BAL, iobase & 0xff); 
+ 
+    /* Enable PP, SSC1, SSC2, FDC, FDC Four-Drive encoding */ 
+ 
+    outb(0x8,SIO_INDEX); 
+    unsigned char id = inb(SIO_DATA);  
+ 
+    print_debug("Super I/O Chip ID: "); 
+    print_debug_hex8(id & 0xf8); 
+    print_debug(" , Revision: "); 
+    print_debug_hex8( id & 3); 
+    print_debug("\r\n"); 
+ 
+ 
+    pc87338_sio_write(NSC87338_CONFIG_REG_FER, 0x1f); 
+ 
+ 
+} 
+ 
Property changes on: src/superio/nsc/pc87338/pc87338_early_serial.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/Config.lb
===================================================================
--- src/mainboard/emulation/vmware/Config.lb    (revision 0) 
+++ src/mainboard/emulation/vmware/Config.lb    (revision 0) 
@@ -0,0 +1,158 @@
+## 
+## Compute the location and size of where this firmware image 
+## (linuxBIOS plus bootloader) will live in the boot rom chip. 
+## 
+if USE_FALLBACK_IMAGE 
+    default ROM_SECTION_SIZE   = FALLBACK_SIZE 
+    default ROM_SECTION_OFFSET = ( ROM_SIZE - FALLBACK_SIZE ) 
+else 
+    default ROM_SECTION_SIZE   = ( ROM_SIZE - FALLBACK_SIZE ) 
+    default ROM_SECTION_OFFSET = 0 
+end 
+ 
+## 
+## Compute the start location and size size of 
+## The linuxBIOS bootloader. 
+## 
+default CONFIG_ROM_PAYLOAD_START = (0xffffffff - ROM_SIZE + ROM_SECTION_OFFSET + 1) 
+default PAYLOAD_SIZE            = ( ROM_SECTION_SIZE - ROM_IMAGE_SIZE ) 
+ 
+## 
+## Compute where this copy of linuxBIOS will start in the boot rom 
+## 
+default _ROMBASE = ( CONFIG_ROM_PAYLOAD_START + PAYLOAD_SIZE ) 
+ 
+## 
+## Compute a range of ROM that can cached to speed up linuxBIOS, 
+## execution speed. 
+## 
+## XIP_ROM_SIZE must be a power of 2. 
+## XIP_ROM_BASE must be a multiple of XIP_ROM_SIZE 
+## 
+default XIP_ROM_SIZE=65536 
+default XIP_ROM_BASE = ( _ROMBASE + ROM_IMAGE_SIZE - XIP_ROM_SIZE ) 
+ 
+## 
+## Set all of the defaults for an x86 architecture 
+## 
+ 
+arch i386 end 
+ 
+## 
+## Build the objects we have code for in this directory. 
+## 
+ 
+driver mainboard.o 
+ 
+if HAVE_PIRQ_TABLE object irq_tables.o end 
+#object reset.o 
+ 
+## 
+## Romcc output 
+## 
+makerule ./failover.E 
+    depends "$(MAINBOARD)/failover.c ./romcc"  
+    action "./romcc -E -O --label-prefix=failover -I$(TOP)/src -I. $(CPPFLAGS) $(MAINBOARD)/failover.c -o $@" 
+end 
+ 
+makerule ./failover.inc 
+    depends "$(MAINBOARD)/failover.c ./romcc" 
+    action "./romcc    -O --label-prefix=failover -I$(TOP)/src -I. $(CPPFLAGS) $(MAINBOARD)/failover.c -o $@" 
+end 
+ 
+makerule ./auto.E  
+    depends    "$(MAINBOARD)/auto.c option_table.h ./romcc"  
+    action    "./romcc -E -mcpu=i386 -O -I$(TOP)/src -I. $(CPPFLAGS) $(MAINBOARD)/auto.c -o $@" 
+end 
+makerule ./auto.inc  
+    depends "$(MAINBOARD)/auto.c option_table.h ./romcc" 
+    action    "./romcc    -mcpu=i386 -O -I$(TOP)/src -I. $(CPPFLAGS) $(MAINBOARD)/auto.c -o $@" 
+end 
+ 
+## 
+## Build our 16 bit and 32 bit linuxBIOS entry code 
+## 
+mainboardinit cpu/x86/16bit/entry16.inc 
+mainboardinit cpu/x86/32bit/entry32.inc 
+ldscript /cpu/x86/16bit/entry16.lds 
+ldscript /cpu/x86/32bit/entry32.lds 
+ 
+## 
+## Build our reset vector (This is where linuxBIOS is entered) 
+## 
+if USE_FALLBACK_IMAGE  
+    mainboardinit cpu/x86/16bit/reset16.inc  
+    ldscript /cpu/x86/16bit/reset16.lds  
+else 
+    mainboardinit cpu/x86/32bit/reset32.inc  
+    ldscript /cpu/x86/32bit/reset32.lds  
+end 
+ 
+### Should this be in the northbridge code? 
+mainboardinit arch/i386/lib/cpu_reset.inc 
+ 
+## 
+## Include an id string (For safe flashing) 
+## 
+mainboardinit arch/i386/lib/id.inc 
+ldscript /arch/i386/lib/id.lds 
+ 
+### 
+### This is the early phase of linuxBIOS startup  
+### Things are delicate and we test to see if we should 
+### failover to another image. 
+### 
+if USE_FALLBACK_IMAGE 
+    ldscript /arch/i386/lib/failover.lds  
+    mainboardinit ./failover.inc 
+end 
+ 
+### 
+### O.k. We aren't just an intermediary anymore! 
+### 
+ 
+## 
+## Setup RAM 
+## 
+mainboardinit cpu/x86/fpu/enable_fpu.inc 
+mainboardinit cpu/x86/mmx/enable_mmx.inc 
+mainboardinit ./auto.inc 
+#mainboardinit arch/i386/llshell/llshell.inc 
+mainboardinit cpu/x86/mmx/disable_mmx.inc 
+ 
+## 
+## Include the secondary Configuration files  
+## 
+dir /pc80 
+config chip.h 
+ 
+chip northbridge/intel/i440bx 
+    device pci_domain 0 on 
+         
+        device pci 00.0 on             # host bridge 
+            chip northbridge/intel/i440bx 
+            end 
+        end    
+         
+        device pci 01.0 on end     # PCI bridge 
+ 
+        device pci 07.0 on         # southbridge  
+                chip southbridge/intel/i82371eb 
+                end 
+        end 
+ 
+        #device pci 0f.0 on end 
+        #chip drivers/pci/onboard 
+        #  device pci f.0 on end 
+        #  register "rom_address" = "0xfff80000" 
+        #end 
+        device pci 10.0 off end     # SCSI storage controller 
+        #device pci 11.0 on end     # Ethernet controller 
+        #device pci 12.0 on end     # Audio controller 
+      end 
+       
+       
+      chip cpu/intel/socket_PGA370 end 
+       
+end 
+ 
Property changes on: src/mainboard/emulation/vmware/Config.lb
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/reset.c
===================================================================
--- src/mainboard/emulation/vmware/reset.c    (revision 0) 
+++ src/mainboard/emulation/vmware/reset.c    (revision 0) 
@@ -0,0 +1,43 @@
+#if 0 
+//#include "arch/romcc_io.h" 
+#include <arch/io.h> 
+ 
+typedef unsigned device_t; 
+ 
+#define PCI_DEV(BUS, DEV, FN) ( \ 
+    (((BUS) & 0xFF) << 16) | \ 
+    (((DEV) & 0x1f) << 11) | \ 
+    (((FN)  & 0x7) << 8)) 
+ 
+static void pci_write_config8(device_t dev, unsigned where, unsigned char value) 
+{ 
+        unsigned addr; 
+        addr = dev | where; 
+        outl(0x80000000 | (addr & ~3), 0xCF8); 
+        outb(value, 0xCFC + (addr & 3)); 
+} 
+ 
+static void pci_write_config32(device_t dev, unsigned where, unsigned value) 
+{ 
+    unsigned addr; 
+        addr = dev | where; 
+        outl(0x80000000 | (addr & ~3), 0xCF8); 
+        outl(value, 0xCFC); 
+} 
+ 
+static unsigned pci_read_config32(device_t dev, unsigned where) 
+{ 
+    unsigned addr; 
+        addr = dev | where; 
+        outl(0x80000000 | (addr & ~3), 0xCF8); 
+        return inl(0xCFC); 
+} 
+ 
+#include "../../../northbridge/amd/amdk8/reset_test.c" 
+ 
+void hard_reset(void) 
+{ 
+    set_bios_reset(); 
+    pci_write_config8(PCI_DEV(1, 0x04, 0), 0x47, 1); 
+} 
+#endif 
Property changes on: src/mainboard/emulation/vmware/reset.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/irq_tables.c
===================================================================
--- src/mainboard/emulation/vmware/irq_tables.c    (revision 0) 
+++ src/mainboard/emulation/vmware/irq_tables.c    (revision 0) 
@@ -0,0 +1,41 @@
+/* This file was generated by getpir.c, do not modify! 
+   (but if you do, please run checkpir on it to verify) 
+ * Contains the IRQ Routing Table dumped directly from your memory, which BIOS sets up 
+ * 
+ * Documentation at : http://www.microsoft.com/hwdev/busbios/PCIIRQ.HTM 
+*/ 
+ 
+ 
+#include <arch/pirq_routing.h> 
+#include <device/pci.h> 
+ 
+const struct irq_routing_table intel_irq_routing_table = { 
+    PIRQ_SIGNATURE,  /* u32 signature */ 
+    PIRQ_VERSION,    /* u16 version   */ 
+    32+16*9,     /* there can be total 9 devices on the bus */ 
+    0x00,         /* Where the interrupt router lies (bus) */ 
+    (0x07<<3)|0x0,   /* Where the interrupt router lies (dev) */ 
+    0,         /* IRQs devoted exclusively to PCI usage */ 
+    0x8086,         /* Vendor */ 
+    0x122e,         /* Device */ 
+    0,         /* Crap (miniport) */ 
+    { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }, /* u8 rfu[11] */ 
+    0x1c,         /*  u8 checksum , this hase to set to some value that would give 0 after the sum of all bytes for this structure (including checksum) */ 
+    { 
+        /* bus,     dev|fn,   {link, bitmap}, {link, bitmap}, {link, bitmap}, {link, bitmap},  slot, rfu */ 
+        {0x00,(0x0f<<3)|0x0, {{0x60, 0xdef8}, {0x61, 0xdef8}, {0x62, 0xdef8}, {0x63, 0x0def8}}, 0x1, 0x0}, 
+        {0x00,(0x10<<3)|0x0, {{0x61, 0xdef8}, {0x62, 0xdef8}, {0x63, 0xdef8}, {0x60, 0x0def8}}, 0x2, 0x0}, 
+        {0x00,(0x11<<3)|0x0, {{0x62, 0xdef8}, {0x63, 0xdef8}, {0x60, 0xdef8}, {0x61, 0x0def8}}, 0x3, 0x0}, 
+        {0x00,(0x12<<3)|0x0, {{0x63, 0xdef8}, {0x60, 0xdef8}, {0x61, 0xdef8}, {0x62, 0x0def8}}, 0x4, 0x0}, 
+        {0x00,(0x13<<3)|0x0, {{0x60, 0xdef8}, {0x61, 0xdef8}, {0x62, 0xdef8}, {0x63, 0x0def8}}, 0x5, 0x0}, 
+        {0x00,(0x14<<3)|0x0, {{0x61, 0xdef8}, {0x62, 0xdef8}, {0x63, 0xdef8}, {0x60, 0x0def8}}, 0x6, 0x0}, 
+        {0x00,(0x00<<3)|0x0, {{0x60, 0xdef8}, {0x61, 0xdef8}, {0x62, 0xdef8}, {0x63, 0x0def8}}, 0x0, 0x0}, 
+        {0x00,(0x07<<3)|0x0, {{0x60, 0xdef8}, {0x61, 0xdef8}, {0x62, 0xdef8}, {0x63, 0x0def8}}, 0x0, 0x0}, 
+        {0x00,(0x01<<3)|0x0, {{0x60, 0xdef8}, {0x61, 0xdef8}, {0x00, 0xdef8}, {0x00, 0x0def8}}, 0x0, 0x0}, 
+    } 
+}; 
+ 
+unsigned long write_pirq_routing_table(unsigned long addr) 
+{ 
+        return copy_pirq_routing_table(addr); 
+} 
Property changes on: src/mainboard/emulation/vmware/irq_tables.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/debug.c
===================================================================
--- src/mainboard/emulation/vmware/debug.c    (revision 0) 
+++ src/mainboard/emulation/vmware/debug.c    (revision 0) 
@@ -0,0 +1,66 @@
+ 
+static void print_debug_pci_dev(unsigned dev) 
+{ 
+    print_debug("PCI: "); 
+    print_debug_hex8((dev >> 16) & 0xff); 
+    print_debug_char(':'); 
+    print_debug_hex8((dev >> 11) & 0x1f); 
+    print_debug_char('.'); 
+    print_debug_hex8((dev >> 8) & 7); 
+} 
+ 
+static void print_pci_devices(void) 
+{ 
+    device_t dev; 
+    for(dev = PCI_DEV(0, 0, 0);  
+        dev <= PCI_DEV(0, 0x1f, 0x7);  
+        dev += PCI_DEV(0,0,1)) { 
+        uint32_t id; 
+        id = pci_read_config32(dev, PCI_VENDOR_ID); 
+        if (((id & 0xffff) == 0x0000) || ((id & 0xffff) == 0xffff) || 
+            (((id >> 16) & 0xffff) == 0xffff) || 
+            (((id >> 16) & 0xffff) == 0x0000)) { 
+            continue; 
+        } 
+        print_debug_pci_dev(dev); 
+        print_debug("\r\n"); 
+    } 
+} 
+ 
+static void dump_pci_device(unsigned dev) 
+{ 
+    int i; 
+    print_debug_pci_dev(dev); 
+    print_debug("\r\n"); 
+     
+    for(i = 0; i <= 255; i++) { 
+        unsigned char val; 
+        if ((i & 0x0f) == 0) { 
+            print_debug_hex8(i); 
+            print_debug_char(':'); 
+        } 
+        val = pci_read_config8(dev, i); 
+        print_debug_char(' '); 
+        print_debug_hex8(val); 
+        if ((i & 0x0f) == 0x0f) { 
+            print_debug("\r\n"); 
+        } 
+    } 
+} 
+ 
+static void dump_pci_devices(void) 
+{ 
+    device_t dev; 
+    for(dev = PCI_DEV(0, 0, 0);  
+        dev <= PCI_DEV(0, 0x1f, 0x7);  
+        dev += PCI_DEV(0,0,1)) { 
+        uint32_t id; 
+        id = pci_read_config32(dev, PCI_VENDOR_ID); 
+        if (((id & 0xffff) == 0x0000) || ((id & 0xffff) == 0xffff) || 
+            (((id >> 16) & 0xffff) == 0xffff) || 
+            (((id >> 16) & 0xffff) == 0x0000)) { 
+            continue; 
+        } 
+        dump_pci_device(dev); 
+    } 
+} 
Property changes on: src/mainboard/emulation/vmware/debug.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/Options.lb
===================================================================
--- src/mainboard/emulation/vmware/Options.lb    (revision 0) 
+++ src/mainboard/emulation/vmware/Options.lb    (revision 0) 
@@ -0,0 +1,173 @@
+uses HAVE_MP_TABLE 
+uses HAVE_PIRQ_TABLE 
+uses USE_FALLBACK_IMAGE 
+uses HAVE_FALLBACK_BOOT 
+uses HAVE_HARD_RESET 
+uses HAVE_OPTION_TABLE 
+uses USE_OPTION_TABLE 
+uses CONFIG_ROM_PAYLOAD 
+uses IRQ_SLOT_COUNT 
+uses MAINBOARD 
+uses MAINBOARD_VENDOR 
+uses MAINBOARD_PART_NUMBER 
+uses MAINBOARD_PCI_SUBSYSTEM_VENDOR_ID 
+uses MAINBOARD_PCI_SUBSYSTEM_DEVICE_ID 
+uses LINUXBIOS_EXTRA_VERSION 
+uses ARCH 
+uses FALLBACK_SIZE 
+uses STACK_SIZE 
+uses HEAP_SIZE 
+uses ROM_SIZE 
+uses ROM_SECTION_SIZE 
+uses ROM_IMAGE_SIZE 
+uses ROM_SECTION_SIZE 
+uses ROM_SECTION_OFFSET 
+uses CONFIG_ROM_PAYLOAD_START 
+uses CONFIG_COMPRESSED_PAYLOAD_LZMA 
+uses PAYLOAD_SIZE 
+uses _ROMBASE 
+uses _RAMBASE 
+uses XIP_ROM_SIZE 
+uses XIP_ROM_BASE 
+uses HAVE_MP_TABLE 
+uses CROSS_COMPILE 
+uses CC 
+uses HOSTCC 
+uses OBJCOPY 
+uses DEFAULT_CONSOLE_LOGLEVEL 
+uses MAXIMUM_CONSOLE_LOGLEVEL 
+uses CONFIG_CONSOLE_SERIAL8250 
+uses CONFIG_CONSOLE_VGA 
+uses CONFIG_CONSOLE_BTEXT 
+uses TTYS0_BAUD 
+uses TTYS0_BASE 
+uses TTYS0_LCS 
+uses CONFIG_UDELAY_TSC 
+uses CONFIG_SERIAL_POST 
+uses CONFIG_PCI_ROM_RUN 
+ 
+## ROM_SIZE is the size of boot ROM that this board will use. 
+default ROM_SIZE  = 512*1024 
+ 
+### 
+### Build options 
+### 
+ 
+## 
+## Build code for the fallback boot 
+## 
+default HAVE_FALLBACK_BOOT=1 
+ 
+## 
+## no MP table 
+## 
+default HAVE_MP_TABLE=0 
+ 
+## 
+## Build code to reset the motherboard from linuxBIOS 
+## 
+default HAVE_HARD_RESET=0 
+ 
+## 
+## Build code to export a programmable irq routing table 
+## 
+default HAVE_PIRQ_TABLE=0 
+default IRQ_SLOT_COUNT=9 
+ 
+## 
+## Build code to export a CMOS option table 
+## 
+default HAVE_OPTION_TABLE=1 
+ 
+### 
+### LinuxBIOS layout values 
+### 
+ 
+## ROM_IMAGE_SIZE is the amount of space to allow linuxBIOS to occupy. 
+default ROM_IMAGE_SIZE = 196608 
+default FALLBACK_SIZE = 196608 
+ 
+## 
+## Use a small 8K stack 
+## 
+default STACK_SIZE=0x2000 
+ 
+## 
+## Use a small 16K heap 
+## 
+default HEAP_SIZE=0x4000 
+ 
+## 
+## Only use the option table in a normal image 
+## 
+default USE_OPTION_TABLE = !USE_FALLBACK_IMAGE 
+#default USE_OPTION_TABLE = 0 
+ 
+default _RAMBASE = 0x00004000 
+ 
+default CONFIG_ROM_PAYLOAD     = 1 
+ 
+## 
+## The default compiler 
+## 
+default CROSS_COMPILE="" 
+default CC="$(CROSS_COMPILE)gcc -m32" 
+default HOSTCC="gcc" 
+ 
+ 
+default CONFIG_CONSOLE_BTEXT=1 
+default CONFIG_CONSOLE_VGA=1 
+default CONFIG_PCI_ROM_RUN=1 
+ 
+## 
+## The Serial Console 
+## 
+ 
+# To Enable the Serial Console 
+default CONFIG_CONSOLE_SERIAL8250=1 
+#default CONFIG_SERIAL_POST=0 
+ 
+## Select the serial console baud rate 
+default TTYS0_BAUD=115200 
+#default TTYS0_BAUD=57600 
+#default TTYS0_BAUD=38400 
+#default TTYS0_BAUD=19200 
+#default TTYS0_BAUD=9600 
+#default TTYS0_BAUD=4800 
+#default TTYS0_BAUD=2400 
+#default TTYS0_BAUD=1200 
+ 
+# Select the serial console base port 
+default TTYS0_BASE=0x3f8 
+ 
+# Select the serial protocol 
+# This defaults to 8 data bits, 1 stop bit, and no parity 
+default TTYS0_LCS=0x3 
+ 
+## 
+### Select the linuxBIOS loglevel 
+## 
+## EMERG      1   system is unusable                
+## ALERT      2   action must be taken immediately  
+## CRIT       3   critical conditions               
+## ERR        4   error conditions                  
+## WARNING    5   warning conditions                
+## NOTICE     6   normal but significant condition  
+## INFO       7   informational                     
+## DEBUG      8   debug-level messages              
+## SPEW       9   Way too many details              
+ 
+## Request this level of debugging output 
+default  DEFAULT_CONSOLE_LOGLEVEL=8 
+## At a maximum only compile in this level of debugging 
+default  MAXIMUM_CONSOLE_LOGLEVEL=9 
+ 
+default CONFIG_UDELAY_TSC=1 
+ 
+ 
+#default MAINBOARD_PCI_SUBSYSTEM_VENDOR_ID=0xfffe 
+#default MAINBOARD_PCI_SUBSYSTEM_DEVICE_ID=0x15ad 
+default MAINBOARD_VENDOR="VMWare" 
+ 
+end 
+ 
Property changes on: src/mainboard/emulation/vmware/Options.lb
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/failover.c
===================================================================
--- src/mainboard/emulation/vmware/failover.c    (revision 0) 
+++ src/mainboard/emulation/vmware/failover.c    (revision 0) 
@@ -0,0 +1,38 @@
+#define ASSEMBLY 1 
+#include <stdint.h> 
+#include <device/pci_def.h> 
+#include <device/pci_ids.h> 
+#include <arch/io.h> 
+#include <arch/hlt.h> 
+#include "arch/romcc_io.h" 
+#include "pc80/mc146818rtc_early.c" 
+#include "pc80/serial.c" 
+#include "arch/i386/lib/console.c" 
+ 
+static unsigned long main(unsigned long bist) 
+{ 
+ 
+    /* This is the primary cpu how should I boot? */ 
+    if (do_normal_boot()) { 
+        print_debug("Going to boot normal image\n"); 
+        goto normal_image; 
+    } 
+    else { 
+            print_debug("Going to boot fallback image\n"); 
+        goto fallback_image; 
+    } 
+ normal_image: 
+    asm volatile ("jmp __normal_image"  
+        : /* outputs */  
+        : "a" (bist) /* inputs */ 
+        : /* clobbers */ 
+        ); 
+ cpu_reset: 
+    asm volatile ("jmp __cpu_reset" 
+        : /* outputs */  
+        : "a"(bist) /* inputs */ 
+        : /* clobbers */ 
+        ); 
+ fallback_image: 
+    return bist; 
+} 
Property changes on: src/mainboard/emulation/vmware/failover.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/auto.c
===================================================================
--- src/mainboard/emulation/vmware/auto.c    (revision 0) 
+++ src/mainboard/emulation/vmware/auto.c    (revision 0) 
@@ -0,0 +1,154 @@
+/* 
+ * This file is part of the LinuxBIOS project. 
+ *  
+ * Copyright (C) 2007 Ceri Coburn <ceri.coburn@gmail.com> 
+ * 
+ * 
+ * This program is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+ */ 
+ 
+ 
+#define ASSEMBLY 1 
+ 
+#include <stdint.h> 
+#include <device/pci_def.h> 
+#include <arch/io.h> 
+#include <device/pnp_def.h> 
+#include <arch/romcc_io.h> 
+#include <arch/hlt.h> 
+#include "option_table.h" 
+#include "pc80/mc146818rtc_early.c" 
+#include "pc80/serial.c" 
+#include "arch/i386/lib/console.c" 
+#include "ram/ramtest.c" 
+#include "southbridge/intel/i82371eb/i82371eb_early_smbus.c" 
+#include "superio/nsc/pc87338/pc87338_early_serial.c" 
+#include "northbridge/intel/i440bx/raminit.h" 
+#include "cpu/x86/mtrr/earlymtrr.c" 
+#include "cpu/x86/bist.h" 
+ 
+#define SERIAL_DEV PNP_DEV(0, 0) 
+ 
+/* 
+ */ 
+void udelay(int usecs) 
+{ 
+    int i; 
+    for(i = 0; i < usecs; i++) 
+        outb(i&0xff, 0x80); 
+} 
+ 
+#include "debug.c" 
+#include "lib/delay.c" 
+ 
+ 
+static void memreset_setup(void) 
+{ 
+} 
+ 
+static void enable_shadow_ram(void) 
+{ 
+    device_t dev = 0; /* no need to look up 0:0.0 */ 
+    unsigned char shadowreg; 
+    /* dev 0 for southbridge */ 
+    shadowreg = pci_read_config8(dev, 0x63); 
+    /* 0xf0000-0xfffff */ 
+    shadowreg |= 0x30; 
+    pci_write_config8(dev, 0x63, shadowreg); 
+} 
+ 
+static inline int spd_read_byte(unsigned device, unsigned address) 
+{ 
+    unsigned char c; 
+    c = smbus_read_byte(device, address); 
+    return c; 
+} 
+ 
+ 
+#include "northbridge/intel/i440bx/raminit.c" 
+#include "northbridge/intel/i440bx/debug.c" 
+#include "sdram/generic_sdram.c" 
+ 
+static void main(unsigned long bist) 
+{ 
+    static const struct mem_controller cpu[] = { 
+        { 
+         .channel0 = { 
+             (0xa << 3) | 0, 
+             (0xa << 3) | 1, 
+             (0xa << 3) | 2,  
+             (0xa << 3) | 3, 
+             }, 
+         } 
+    }; 
+    unsigned long x; 
+ 
+    if (bist == 0) { 
+        early_mtrr_init(); 
+    } 
+ 
+    pc87338_enable_serial(SERIAL_DEV, TTYS0_BASE); 
+ 
+    uart_init(); 
+    console_init(); 
+ 
+    /* Halt if there was a built in self test failure */ 
+    report_bist_failure(bist); 
+ 
+    enable_smbus(); 
+    //dump_spd_registers(&cpu[0]); 
+ 
+#if 1 
+    enable_shadow_ram(); 
+    /* 
+      memreset_setup(); 
+      this is way more generic than we need. 
+      sdram_initialize(sizeof(cpu)/sizeof(cpu[0]), cpu); 
+    */ 
+    sdram_set_registers((const struct mem_controller *) 0); 
+     
+         
+    /* VMWare automaticlly populates DRB's  within the  
+       440BX DRB registers so there is no need to populate it and 
+       the SPD values seem to be incorrect when reading them anyway. 
+       Any other 440bx base mainboard should call sdram_set_drb 
+        
+    sdram_set_drb((const struct mem_controller *) &cpu[0]);*/ 
+     
+    sdram_set_spd_registers((const struct mem_controller *) &cpu[0]); 
+    sdram_enable(0, (const struct mem_controller *) 0); 
+#endif 
+ 
+    /* Check all of memory */ 
+#if 0 
+    ram_check(0x00000000, msr.lo); 
+#endif 
+#if 0 
+    static const struct { 
+        unsigned long lo, hi; 
+    } check_addrs[] = { 
+        /* Check 16MB of memory @ 0*/ 
+        { 0x00000000, 0x01000000 }, 
+#if TOTAL_CPUS > 1 
+        /* Check 16MB of memory @ 2GB */ 
+        { 0x80000000, 0x81000000 }, 
+#endif 
+    }; 
+    int i; 
+    for(i = 0; i < sizeof(check_addrs)/sizeof(check_addrs[0]); i++) { 
+        ram_check(check_addrs[i].lo, check_addrs[i].hi); 
+    } 
+#endif 
+} 
Property changes on: src/mainboard/emulation/vmware/auto.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/chip.h
===================================================================
--- src/mainboard/emulation/vmware/chip.h    (revision 0) 
+++ src/mainboard/emulation/vmware/chip.h    (revision 0) 
@@ -0,0 +1,5 @@
+extern struct chip_operations mainboard_emulation_vmware_ops; 
+ 
+struct mainboard_emulation_vmware_config { 
+    int nothing; 
+}; 
Property changes on: src/mainboard/emulation/vmware/chip.h
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/cmos.layout
===================================================================
--- src/mainboard/emulation/vmware/cmos.layout    (revision 0) 
+++ src/mainboard/emulation/vmware/cmos.layout    (revision 0) 
@@ -0,0 +1,74 @@
+entries 
+ 
+#start-bit length  config config-ID    name 
+#0            8       r       0        seconds 
+#8            8       r       0        alarm_seconds 
+#16           8       r       0        minutes 
+#24           8       r       0        alarm_minutes 
+#32           8       r       0        hours 
+#40           8       r       0        alarm_hours 
+#48           8       r       0        day_of_week 
+#56           8       r       0        day_of_month 
+#64           8       r       0        month 
+#72           8       r       0        year 
+#80           4       r       0        rate_select 
+#84           3       r       0        REF_Clock 
+#87           1       r       0        UIP 
+#88           1       r       0        auto_switch_DST 
+#89           1       r       0        24_hour_mode 
+#90           1       r       0        binary_values_enable 
+#91           1       r       0        square-wave_out_enable 
+#92           1       r       0        update_finished_enable 
+#93           1       r       0        alarm_interrupt_enable 
+#94           1       r       0        periodic_interrupt_enable 
+#95           1       r       0        disable_clock_updates 
+#96         288       r       0        temporary_filler 
+0          384       r       0        reserved_memory 
+384          1       e       4        boot_option 
+385          1       e       4        last_boot 
+386          1       e       1        ECC_memory 
+388          4       r       0        reboot_bits 
+392          3       e       5        baud_rate 
+400          1       e       1        power_on_after_fail 
+412          4       e       6        debug_level 
+416          4       e       7        boot_first 
+420          4       e       7        boot_second 
+424          4       e       7        boot_third 
+428          4       h       0        boot_index 
+432         8       h       0        boot_countdown 
+1008         16      h       0        check_sum 
+ 
+enumerations 
+ 
+#ID value   text 
+1     0     Disable 
+1     1     Enable 
+2     0     Enable 
+2     1     Disable 
+4     0     Fallback 
+4     1     Normal 
+5     0     115200 
+5     1     57600 
+5     2     38400 
+5     3     19200 
+5     4     9600 
+5     5     4800 
+5     6     2400 
+5     7     1200 
+6     6     Notice 
+6     7     Info 
+6     8     Debug 
+6     9     Spew 
+7     0     Network 
+7     1     HDD 
+7     2     Floppy 
+7     8     Fallback_Network 
+7     9     Fallback_HDD 
+7     10    Fallback_Floppy 
+#7     3     ROM 
+ 
+checksums 
+ 
+checksum 392 1007 1008 
+ 
+ 
Property changes on: src/mainboard/emulation/vmware/cmos.layout
___________________________________________________________________
Name: svn:executable
   + *
Index: src/mainboard/emulation/vmware/mainboard.c
===================================================================
--- src/mainboard/emulation/vmware/mainboard.c    (revision 0) 
+++ src/mainboard/emulation/vmware/mainboard.c    (revision 0) 
@@ -0,0 +1,40 @@
+/* 
+ * This file is part of the LinuxBIOS project. 
+ *  
+ * Copyright (C) 2007 Ceri Coburn <ceri.coburn@gmail.com> 
+ * 
+ * 
+ * This program is free software; you can redistribute it and/or modify 
+ * it under the terms of the GNU General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or 
+ * (at your option) any later version. 
+ * 
+ * This program is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * GNU General Public License for more details. 
+ * 
+ * You should have received a copy of the GNU General Public License 
+ * along with this program; if not, write to the Free Software 
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA 
+ */ 
+ 
+#include <device/device.h> 
+#include "chip.h" 
+#include <pc80/keyboard.h> 
+#include <console/console.h> 
+ 
+static void vmware_init(struct device* dev) 
+{ 
+    printk_debug("Initializing VMWare keyboard\n"); 
+    init_pc_keyboard(0x60,0x64,0); 
+     
+} 
+ 
+ 
+ 
+struct chip_operations mainboard_emulation_vmware_ops = { 
+    CHIP_NAME("VMWare Workstation") 
+    .enable_dev = vmware_init 
+}; 
+ 
Property changes on: src/mainboard/emulation/vmware/mainboard.c
___________________________________________________________________
Name: svn:executable
   + *
Index: src/northbridge/intel/i440bx/i440bx.h
===================================================================
--- src/northbridge/intel/i440bx/i440bx.h    (revision 2639) 
+++ src/northbridge/intel/i440bx/i440bx.h    (working copy) 
@@ -62,7 +62,17 @@
 #define EAP     0x80 /* Error Address Pointer Register (0x00000000). */
 #define ERRCMD  0x90 /* Error Command Register (0x80). */
 #define ERRSTS  0x91 /* Error Status (0x0000). */
+ 
 // TODO: AGP stuff.
+#define ACAPID  0xa0 /* AGP Capability Identifier Register (Device 0) */ 
+#define AGPSTAT 0xa4 /* AGP Status Register */ 
+#define AGPCMD  0xa8 /* AGP Command Register */ 
+#define AGPCTRL 0xb0 /* AGP Control Register */ 
+#define APSIZE  0xb4 /* Aperture Size Register */ 
+#define ATTBASE 0xb8 /* Aperture Translation Table Base */ 
+ 
+ 
+ 
 #define MBFS    0xca /* Memory Buffer Frequency Select (0x000000). */
 #define BSPAD   0xd0 /* BIOS Scratch Pad (0x000..000). */
 #define DWTC    0xe0 /* DRAM Write Thermal Throttling Control (0x000..000). */
Index: src/northbridge/intel/i440bx/raminit.c
===================================================================
--- src/northbridge/intel/i440bx/raminit.c    (revision 2639) 
+++ src/northbridge/intel/i440bx/raminit.c    (working copy) 
@@ -181,13 +181,13 @@
      * 11 = Read/Write (all access goes to DRAM)
      */
     // TODO
-    PAM0, 0x00000000, 0x00, 
-    PAM1, 0x00000000, 0x00, 
-    PAM2, 0x00000000, 0x00, 
+    PAM0, 0x00000000, 0x10, 
+    PAM1, 0x00000000, 0x11, 
+    PAM2, 0x00000000, 0x01, 
     PAM3, 0x00000000, 0x00,
-    PAM4, 0x00000000, 0x00, 
-    PAM5, 0x00000000, 0x00, 
-    PAM6, 0x00000000, 0x00, 
+    PAM4, 0x00000000, 0x30, 
+    PAM5, 0x00000000, 0x13, 
+    PAM6, 0x00000000, 0x11, 
 
     /* DRB[0:7] - DRAM Row Boundary Registers
      * 0x60 - 0x67
@@ -439,49 +439,80 @@
     }
 }
 
+ 
 /**
  * TODO.
  *
  * @param Memory controller
  */
+static void sdram_set_drb(const struct mem_controller *ctrl) 
+{ 
+    /* TODO: Don't hardcode the values here, get info via SPD. */ 
+     
+    /* TODO: Set DRB0-DRB7. */ 
+ 
+    pci_write_config8(ctrl->d0, DRB0, 0x40); 
+    pci_write_config8(ctrl->d0, DRB1, 0x80); 
+    pci_write_config8(ctrl->d0, DRB2, 0x80); 
+    pci_write_config8(ctrl->d0, DRB3, 0x80); 
+    pci_write_config8(ctrl->d0, DRB4, 0x80); 
+    pci_write_config8(ctrl->d0, DRB5, 0x80); 
+    pci_write_config8(ctrl->d0, DRB6, 0x80); 
+    pci_write_config8(ctrl->d0, DRB7, 0x80); 
+} 
+ 
+  
+/** 
+ * TODO. 
+ * 
+ * @param Memory controller 
+ */  
 static void sdram_set_spd_registers(const struct mem_controller *ctrl)
 {
     /* TODO: Don't hardcode the values here, get info via SPD. */
+     
+     
+    //set PAM maps 
+    pci_write_config8(ctrl->d0, PAM0, 0x30); 
+    pci_write_config8(ctrl->d0, PAM1, 0x33); 
+    pci_write_config8(ctrl->d0, PAM2, 0x33); 
+    pci_write_config8(ctrl->d0, PAM3, 0x33); 
+    pci_write_config8(ctrl->d0, PAM4, 0x33); 
+    pci_write_config8(ctrl->d0, PAM5, 0); 
+    pci_write_config8(ctrl->d0, PAM6, 0); 
 
-    /* TODO: Set DRB0-DRB7. */ 
-    pci_write_config8(ctrl->d0, DRB0, 0x08); 
-    pci_write_config8(ctrl->d0, DRB1, 0x08); 
-    pci_write_config8(ctrl->d0, DRB2, 0x08); 
-    pci_write_config8(ctrl->d0, DRB3, 0x08); 
-    pci_write_config8(ctrl->d0, DRB4, 0x08); 
-    pci_write_config8(ctrl->d0, DRB5, 0x08); 
-    pci_write_config8(ctrl->d0, DRB6, 0x08); 
-    pci_write_config8(ctrl->d0, DRB7, 0x08); 
- 
     /* TODO: Set DRAMC. Don't enable refresh for now. */
     pci_write_config8(ctrl->d0, DRAMC, 0x08);
 
     /* TODO: Set RPS. */
-    pci_write_config16(ctrl->d0, RPS, 0x0001); 
+    pci_write_config16(ctrl->d0, RPS, 0x0000); 
 
     /* TODO: Set SDRAMC. */
     // pci_write_config16(ctrl->d0, SDRAMC, 0x0000);
 
     /* TODO: Set PGPOL. */
-    pci_write_config16(ctrl->d0, PGPOL, 0x0107); 
+    pci_write_config16(ctrl->d0, PGPOL, 0xff00); 
 
     /* TODO: Set NBXCFG. */
-    // pci_write_config32(ctrl->d0, NBXCFG, 0x0100220c); 
+    pci_write_config32(ctrl->d0, NBXCFG, 0xff00a00c); 
 
+     
+    /* TODO: Set RPS. */ 
+    pci_write_config8(ctrl->d0, SMRAM, 0x8);         
+ 
+    //pci_write_config8(ctrl->d0,ATTBASE,0x3); 
+ 
+ 
     /* TODO: Set PMCR? */
     // pci_write_config8(ctrl->d0, PMCR, 0x14);
     // pci_write_config8(ctrl->d0, PMCR, 0x10);
 
     /* TODO? */
     // pci_write_config8(ctrl->d0, MLT, 0x40);
-    // pci_write_config8(ctrl->d0, DRAMT, 0x03); 
+    //pci_write_config8(ctrl->d0, DRAMT, 0x03); 
     // pci_write_config8(ctrl->d0, MBSC, 0x03);
     // pci_write_config8(ctrl->d0, SCRR, 0x38);
+     
 }
 
 /**
Index: src/northbridge/intel/i440bx/northbridge.c
===================================================================
--- src/northbridge/intel/i440bx/northbridge.c    (revision 2639) 
+++ src/northbridge/intel/i440bx/northbridge.c    (working copy) 
@@ -112,7 +112,10 @@
          * the physical memory.  The units are ticks of 8MB
          * i.e. 1 means 8MB.
          */
-        tomk = ((unsigned long)pci_read_config8(mc_dev, DRB7)) << 15; 
+        tomk = ((unsigned long)pci_read_config8(mc_dev, DRB7)) << 13; 
+         
+        printk_debug("I would like to set RAM size to %dMB\n",tomk >> 10); 
+         
         /* Compute the top of Low memory */
         tolmk = pci_tolm >> 10;
         if (tolmk >= tomk) {
